@@ -8,7 +8,7 @@ package Tickit::Test;
 use strict;
 use warnings;
 
-our $VERSION = '0.29';
+our $VERSION = '0.30';
 
 use Exporter 'import';
 
@@ -48,6 +48,8 @@ use Tickit::Test::MockTerm;
 use Tickit::Pen;
 use Tickit;
 
+use Tickit::Utils qw( textwidth substrwidth );
+
 use Test::Builder;
 
 =head1 NAME
@@ -208,7 +210,7 @@ sub resize_term
    $tickit->rootwin->resize( $tickit->lines, $tickit->cols );
 }
 
-=head2 presskey( $type, $str )
+=head2 presskey( $type, $str, $mod )
 
 Fire a key event
 
@@ -216,13 +218,12 @@ Fire a key event
 
 sub presskey
 {
-   my ( $type, $str ) = @_;
+   my ( $type, $str, $mod ) = @_;
 
-   # TODO: See if we'll ever need to fake a Term::TermKey::Key event object
-   $tickit->on_key( $type, $str, undef );
+   $tickit->on_key( $type, $str, $mod||0 );
 }
 
-=head2 pressmouse( $ev, $button, $line, $col )
+=head2 pressmouse( $ev, $button, $line, $col, $mod )
 
 Fire a mouse button event
 
@@ -230,9 +231,9 @@ Fire a mouse button event
 
 sub pressmouse
 {
-   my ( $ev, $button, $line, $col ) = @_;
+   my ( $ev, $button, $line, $col, $mod ) = @_;
 
-   $tickit->on_mouse( $ev, $button, $line, $col );
+   $tickit->on_mouse( $ev, $button, $line, $col, $mod||0 );
 }
 
 =head1 TEST FUNCTIONS
@@ -367,7 +368,7 @@ sub is_display
 
             $want_text .= " " x ( $term->cols - $col ) unless defined $want_text and length $want_text;
 
-            my $got_text = $term->get_display_text( $line, $col, length $want_text );
+            my $got_text = $term->get_display_text( $line, $col, textwidth $want_text );
             if( $got_text ne $want_text ) {
                my $ok = $tb->ok( 0, $name );
                $tb->diag( "Display differs on line $line at column $col" );
@@ -378,8 +379,8 @@ sub is_display
 
             my $want_pen = _pen2string( $chunk->[1] );
             my $idx = 0;
-            while( $idx < length $want_text ) {
-               if( substr( $want_text, $idx, 1 ) eq " " ) {
+            while( $idx < textwidth $want_text ) {
+               if( substrwidth( $want_text, $idx, 1 ) eq " " ) {
                   my $want_bg = $chunk->[1]->{bg} // "undef";
                   my $got_bg = $term->get_display_pen( $line, $col )->{bg} // "undef";
                   if( $got_bg ne $want_bg ) {
